thoughtsforge.db-actions

DynamoDB Single Table Design Operations.

Performs operations on DynamoDB tables following the single table design pattern. Multiple entity types are stored in one table using composite primary keys (pk/sk) and GSIs to support various access patterns.

Key conventions:

  • pk, pk1, pk2, ... : Partition key columns (pk for main table, pk1+ for GSIs)
  • sk, sk1, sk2, ... : Sort key columns (sk for main table, sk1+ for GSIs)
  • GSI naming: gsiPk{n}Sk{m} (e.g., gsiPkSk1, gsiPk1Sk2)
  • creationTime: Automatically set on first insert (immutable)
  • updateTime: Automatically updated on every upsert

Attribute values are marshalled to and from DynamoDB types automatically:

  • written: nil -> NULL, string -> S, number -> N, boolean -> BOOL, byte array / ByteBuffer -> B, map -> M, sequential -> L
  • read: the above plus SS and NS (as sets) and BS (as a vector of byte arrays) Binary attributes are read back as byte arrays. Strings are always written as S, never as binary. pk/sk values must not be binary.
DynamoDB Single Table Design Operations.

Performs operations on DynamoDB tables following the single table design pattern.
Multiple entity types are stored in one table using composite primary keys (pk/sk)
and GSIs to support various access patterns.

Key conventions:
  - pk, pk1, pk2, ... : Partition key columns (pk for main table, pk1+ for GSIs)
  - sk, sk1, sk2, ... : Sort key columns (sk for main table, sk1+ for GSIs)
  - GSI naming: gsiPk{n}Sk{m} (e.g., gsiPkSk1, gsiPk1Sk2)
  - creationTime: Automatically set on first insert (immutable)
  - updateTime: Automatically updated on every upsert

Attribute values are marshalled to and from DynamoDB types automatically:
  - written: nil -> NULL, string -> S, number -> N, boolean -> BOOL,
    byte array / ByteBuffer -> B, map -> M, sequential -> L
  - read: the above plus SS and NS (as sets) and BS (as a vector of byte arrays)
Binary attributes are read back as byte arrays. Strings are always written as S,
never as binary. pk/sk values must not be binary.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries